@@ -53,6 +53,7 @@ G_BEGIN_DECLS
 #define GAPC_SYSTRAY_KEY     "/apps/gapcmon/monitor/%d/use_systray"
 #define GAPC_PAGER_KEY       "/apps/gapcmon/monitor/%d/skip_pagers"     /* not used */
 #define GAPC_PORT_KEY        "/apps/gapcmon/monitor/%d/port_number"
+#define GAPC_WATT_KEY        "/apps/gapcmon/monitor/%d/ups_wattage"
 #define GAPC_REFRESH_KEY     "/apps/gapcmon/monitor/%d/network_interval"
 #define GAPC_GRAPH_KEY       "/apps/gapcmon/monitor/%d/graph_interval"
 #define GAPC_HOST_KEY        "/apps/gapcmon/monitor/%d/host_name"
@@ -65,6 +66,7 @@ G_BEGIN_DECLS
 #define GAPC_REFRESH_FACTOR_ONE_TIME 500
 #define GAPC_HOST_DEFAULT "localhost"
 #define GAPC_PORT_DEFAULT 3551
+#define GAPC_WATT_DEFAULT 600
 #define GAPC_REFRESH_DEFAULT 8.0
 #define GAPC_REFRESH_MIN_INCREMENT 1.0  /* Minimum refresh cycle seconds */
 #define GAPC_LINEGRAPH_XMAX 40
@@ -131,6 +133,7 @@ typedef enum _Prefs_Store_IDs {
    GAPC_PREFS_REFRESH,
    GAPC_PREFS_GRAPH,
    GAPC_PREFS_HOST,
+   GAPC_PREFS_WATT,
    GAPC_N_PREFS_COLUMNS
 } GAPC_PrefsType;
 
@@ -147,6 +150,7 @@ typedef struct _Preferences_Key_Records {
    gchar k_enabled[GAPC_MAX_TEXT];
    gchar k_use_systray[GAPC_MAX_TEXT];
    gchar k_port_number[GAPC_MAX_TEXT];
+   gchar k_watt_number[GAPC_MAX_TEXT];
    gchar k_network_interval[GAPC_MAX_TEXT];
    gchar k_graph_interval[GAPC_MAX_TEXT];
    gchar k_host_name[GAPC_MAX_TEXT];
@@ -287,6 +291,7 @@ typedef struct _Monitor_Instance_Data {
    gboolean cb_use_systray;
    gchar *pch_host;
    gint i_port;
+   gint i_watt;   
    gfloat d_refresh;
    gfloat d_graph;                 /* End Preference values */
 
